# User


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email** | **str** |  | 
**id** | **int** |  | [readonly] 
**first_name** | **str** |  | [optional] 
**last_name** | **str** |  | [optional] 
**is_beta_tester** | **bool** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


